==> google_cloud_shell-1.2.1-py2.py3-none-any.whl: google/cloud/shell_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.cloud_shell_service import CloudShellServiceClient
from .services.cloud_shell_service import CloudShellServiceAsyncClient

from .types.cloudshell import AddPublicKeyMetadata
from .types.cloudshell import AddPublicKeyRequest
from .types.cloudshell import AddPublicKeyResponse
from .types.cloudshell import AuthorizeEnvironmentMetadata
from .types.cloudshell import AuthorizeEnvironmentRequest
from .types.cloudshell import AuthorizeEnvironmentResponse
from .types.cloudshell import CloudShellErrorDetails
from .types.cloudshell import CreateEnvironmentMetadata
from .types.cloudshell import DeleteEnvironmentMetadata
from .types.cloudshell import Environment
from .types.cloudshell import GetEnvironmentRequest
from .types.cloudshell import RemovePublicKeyMetadata
from .types.cloudshell import RemovePublicKeyRequest
from .types.cloudshell import RemovePublicKeyResponse
from .types.cloudshell import StartEnvironmentMetadata
from .types.cloudshell import StartEnvironmentRequest
from .types.cloudshell import StartEnvironmentResponse

__all__ = (
    "CloudShellServiceAsyncClient",
    "AddPublicKeyMetadata",
    "AddPublicKeyRequest",
    "AddPublicKeyResponse",
    "AuthorizeEnvironmentMetadata",
    "AuthorizeEnvironmentRequest",
    "AuthorizeEnvironmentResponse",
    "CloudShellErrorDetails",
    "CloudShellServiceClient",
    "CreateEnvironmentMetadata",
    "DeleteEnvironmentMetadata",
    "Environment",
    "GetEnvironmentRequest",
    "RemovePublicKeyMetadata",
    "RemovePublicKeyRequest",
    "RemovePublicKeyResponse",
    "StartEnvironmentMetadata",
    "StartEnvironmentRequest",
    "StartEnvironmentResponse",
)

==> google_cloud_shell-1.4.3-py2.py3-none-any.whl: google/cloud/shell_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.cloud_shell_service import (
    CloudShellServiceAsyncClient,
    CloudShellServiceClient,
)
from .types.cloudshell import (
    AddPublicKeyMetadata,
    AddPublicKeyRequest,
    AddPublicKeyResponse,
    AuthorizeEnvironmentMetadata,
    AuthorizeEnvironmentRequest,
    AuthorizeEnvironmentResponse,
    CloudShellErrorDetails,
    CreateEnvironmentMetadata,
    DeleteEnvironmentMetadata,
    Environment,
    GetEnvironmentRequest,
    RemovePublicKeyMetadata,
    RemovePublicKeyRequest,
    RemovePublicKeyResponse,
    StartEnvironmentMetadata,
    StartEnvironmentRequest,
    StartEnvironmentResponse,
)

__all__ = (
    "CloudShellServiceAsyncClient",
    "AddPublicKeyMetadata",
    "AddPublicKeyRequest",
    "AddPublicKeyResponse",
    "AuthorizeEnvironmentMetadata",
    "AuthorizeEnvironmentRequest",
    "AuthorizeEnvironmentResponse",
    "CloudShellErrorDetails",
    "CloudShellServiceClient",
    "CreateEnvironmentMetadata",
    "DeleteEnvironmentMetadata",
    "Environment",
    "GetEnvironmentRequest",
    "RemovePublicKeyMetadata",
    "RemovePublicKeyRequest",
    "RemovePublicKeyResponse",
    "StartEnvironmentMetadata",
    "StartEnvironmentRequest",
    "StartEnvironmentResponse",
)
